aboutsummaryrefslogtreecommitdiffstats
path: root/engine/predefs17_2.asm
diff options
context:
space:
mode:
authoryenatch <yenatch@gmail.com>2014-05-26 14:04:56 -0700
committeryenatch <yenatch@gmail.com>2014-05-26 22:04:39 -0700
commit40c17c906b2b3f65b3b04b1933b90238a7ac5566 (patch)
tree6de26c959808d5a792b692f2300c33557c1dbfab /engine/predefs17_2.asm
parentDon't hardcode wram sections (except for alignment). (diff)
downloadpokeyellow-40c17c906b2b3f65b3b04b1933b90238a7ac5566.tar.gz
pokeyellow-40c17c906b2b3f65b3b04b1933b90238a7ac5566.tar.xz
pokeyellow-40c17c906b2b3f65b3b04b1933b90238a7ac5566.zip
Remove most static wram addresses. Use labels instead.
For unknown addresses, use "w<address>". Label overleads are still an issue.
Diffstat (limited to 'engine/predefs17_2.asm')
-rwxr-xr-xengine/predefs17_2.asm6
1 files changed, 3 insertions, 3 deletions
diff --git a/engine/predefs17_2.asm b/engine/predefs17_2.asm
index c2cbefc2..4cda1db3 100755
--- a/engine/predefs17_2.asm
+++ b/engine/predefs17_2.asm
@@ -1,10 +1,10 @@
; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in $d11e
SetPartyMonTypes: ; 5db5e (17:5b5e)
call GetPredefRegisters
ld bc, W_PARTYMON1_TYPE1 - W_PARTYMON1DATA ; $5
add hl, bc
- ld a, [$d11e]
- ld [$d0b5], a
+ ld a, [wd11e]
+ ld [wd0b5], a
push hl
call GetMonHeader
pop hl
@@ -1,10 +1,10 @@
-; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in $d11e
+; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in wd11e
SetPartyMonTypes: ; 5db5e (17:5b5e)
call GetPredefRegisters